--Projeto SNGPC
/*
  - Configurar setores que representam produtos controlados SNGPC
  - Definir Função SNGPC_alterar_sugestao_lotes_SNGPC_Xml para usuário que permitirá alterar lotes
  - Endereçar produtos(novos), visto que a identificação se o produto tem controle SNGPC se dar pelo Setor;
  - 
*/
IF Not (EXISTS (SELECT * FROM INFORMATION_SCHEMA.TABLES 
                WHERE TABLE_NAME = 'TbIntegracaoSaidaAuditoriaItec')) BEGIN
/****** Object:  Table [dbo].[TbIntegracaoSaidaAuditoriaItec]    Script Date: 04/11/2020 14:09:00 ******/
	SET ANSI_NULLS ON
--	GO

	SET QUOTED_IDENTIFIER ON
--	GO
	
	CREATE TABLE [dbo].[TbIntegracaoSaidaAuditoriaItec](
		[DataHora] [datetime] NULL,
		[PEDIDO] [varchar](7) NOT NULL,
		[COD_PROD] [varchar](15) NOT NULL,
		[QUANTIDADE] [float] NULL,
		[ROTA] [smallint] NULL,
		[NR_CLI] [int] NULL,
		[NM_CLI] [nvarchar](100) NULL,
		[CROSSDOCKING] [int] NOT NULL,
		[DOCUMENTO] [int] NULL,
		[DT_PEDIDO] [datetime] NULL,
		[EMBALAGEM] [float] NOT NULL
	) ON [PRIMARY]
--	GO
	
	ALTER TABLE [dbo].[TbIntegracaoSaidaAuditoriaItec] ADD  CONSTRAINT [DF_SAIDA_LEG_CROSSDOCKING_IntrSaidaItec]  DEFAULT ((0)) FOR [CROSSDOCKING]
--	GO
	
	ALTER TABLE [dbo].[TbIntegracaoSaidaAuditoriaItec] ADD  CONSTRAINT [DF_SAIDA_LEG_DOCUMENTO_IntrSaidaItec]  DEFAULT ((0)) FOR [DOCUMENTO]
--	GO
	
	ALTER TABLE [dbo].[TbIntegracaoSaidaAuditoriaItec] ADD  CONSTRAINT [DF_SAIDA_LEG_EMBALAGEM_IntrSaidaItec]  DEFAULT ((1)) FOR [EMBALAGEM]
--	GO
	
	
	/****** Object:  Trigger [dbo].[tgAuditoriaSaidaItec]    Script Date: 04/11/2020 14:08:29 ******/
	SET ANSI_NULLS ON
--	GO
	
	SET QUOTED_IDENTIFIER ON
--	GO
End;

SET ANSI_NULLS ON;
SET QUOTED_IDENTIFIER ON;
IF(EXISTS(SELECT * FROM  sys.triggers WHERE NAME = 'tgAuditoriaSaidaItec'))
    BEGIN
        DROP TRIGGER [dbo].tgAuditoriaSaidaItec;
    END;
GO

	CREATE TRIGGER [dbo].[tgAuditoriaSaidaItec] ON [dbo].[SAIDA_LEG] AFTER INSERT AS 
	BEGIN
		SET NOCOUNT ON;

		insert into TbIntegracaoSaidaAuditoriaItec (
						DataHora
						, PEDIDO	
						, COD_PROD	
						, QUANTIDADE	
						, ROTA	
						, NR_CLI	
						, NM_CLI	
						, CROSSDOCKING	
						, DOCUMENTO	
						, DT_PEDIDO	
						, EMBALAGEM	)
	
		select
			GETDATE()
			, PEDIDO	
			, COD_PROD	
			, QUANTIDADE	
			, ROTA	
			, NR_CLI	
			, NM_CLI	
			, CROSSDOCKING	
			, DOCUMENTO	
			, DT_PEDIDO	
			, EMBALAGEM
		from
			inserted
	END
	
	ALTER TABLE [dbo].[SAIDA_LEG] ENABLE TRIGGER [tgAuditoriaSaidaItec]



IF not EXISTS( SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'TbEnderecoSetor' AND COLUMN_NAME = 'ControlSNGPC') begin
 	Alter Table TbEnderecoSetor
       Add ControlSNGPC Bit Default 0
End;

/****** Object:  View [dbo].[vwProduto]    Script Date: 04/11/2020 16:43:40 ******/
SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO

ALTER VIEW [dbo].[vwProduto]
AS
SELECT        prd.cdProduto, prd.nmProduto, COALESCE (ean.nmEAN, '') AS nmEAN, prd.Embalagem, prd.Altura, prd.Largura, prd.Comprimento, prd.Volume, prd.Peso, prd.Liquido, COALESCE (prd.EstoqueMinimo, 0) 
                         AS EstoqueMinimo, COALESCE (prd.EstoqueMaximo, 0) AS EstoqueMaximo, COALESCE (prd.ValidadeMinimaEntrada, prm1.entValidadeMinimaPadrao) AS ValidadeMinimaEntrada, DATEADD(month, 
                         COALESCE (prd.ValidadeMinimaEntrada, prm1.entValidadeMinimaPadrao), DATEADD(d, 0, DATEDIFF(d, 0, GETDATE()))) AS dtValidadeMinimaEntrada, COALESCE (prd.ValidadeMinimaSaida, 
                         prm2.saiValidadeMinimaPadrao) AS ValidadeMinimaSaida, DATEADD(month, COALESCE (prd.ValidadeMinimaSaida, prm2.saiValidadeMinimaPadrao), DATEADD(d, 0, DATEDIFF(d, 0, GETDATE()))) 
                         AS dtValidadeMinimaSaida, fbr.cdFabricante, fbr.nmFabricante, COALESCE (edr.cdEndereco, 0) AS cdEndereco, COALESCE (edr.nmEndereco, '') AS nmEndereco, 
						 TpE.NmEnderecoTipo, COALESCE (str.cdEnderecoSetor, 0) 
                         AS cdEnderecoSetor, COALESCE (str.nmEnderecoSetor, 'SEM ENDEREÇO') AS nmEnderecoSetor, COALESCE (rua.cdEnderecoRua, 0) AS cdEnderecoRua, COALESCE (rua.nmEnderecoRua, '') AS nmEnderecoRua, 
                         cnt1.cdProdutoControle,
						 cnt1.nmProdutoControle
FROM            tbProduto AS prd WITH (READUNCOMMITTED)
INNER JOIN tbProdutoControle AS cnt1 ON prd.cdProdutoControle = cnt1.cdProdutoControle 
INNER JOIN tbFabricante AS fbr ON prd.cdFabricante = fbr.cdFabricante
LEFT JOIN tbProdutoEAN AS ean WITH (READUNCOMMITTED) ON prd.cdProduto = ean.cdProduto AND ean.Principal = 1 LEFT JOIN
                         tbEndereco AS edr ON prd.cdEndereco = edr.cdEndereco 
						 Left Join TbEnderecoTipo TpE On Edr.cdEnderecoTipo = TpE.cdEnderecoTipo
                         LEFT JOIN tbEnderecoSetor AS str ON edr.cdEnderecoSetor = str.cdEnderecoSetor LEFT JOIN
                         tbEnderecoRua AS rua ON edr.cdEnderecoRua = rua.cdEnderecoRua LEFT JOIN
                         tbProdutoControle AS cnt2 ON str.cdProdutoControle = cnt2.cdProdutoControle CROSS apply
                             (SELECT        CAST(vlParametro AS int) AS entValidadeMinimaPadrao
                               FROM            tbParametro
                               WHERE        nmParametro = 'entValidadeMinimaPadrao') AS prm1 CROSS apply
                             (SELECT        CAST(vlParametro AS int) AS saiValidadeMinimaPadrao
                               FROM            tbParametro
                               WHERE        nmParametro = 'saiValidadeMinimaPadrao') AS prm2
GO



IF not EXISTS(SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'TbEntrada' AND
   COLUMN_NAME = 'DtChegadaCarga') begin
   Alter Table TbEntrada

     Add DtChegadaCarga Date
End;
IF not EXISTS(SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'TbEntrada' AND
   COLUMN_NAME = 'HrChegadaCarga') begin
   Alter Table TbEntrada
      Add HrChegadaCarga Time(7)
End;
IF not EXISTS(SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'TbEntrada' AND
   COLUMN_NAME = 'TpMarcacao') begin
   Alter Table TbEntrada
      Add TpMarcacao Int
End;
IF not EXISTS(SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'TbEntrada' AND
   COLUMN_NAME = 'CdUsuarioAuth') begin
   Alter Table TbEntrada
   Add CdUsuarioAuth Int
End;
IF not EXISTS(SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'TbEntradaProduto' AND
   COLUMN_NAME = 'DtConfIni') begin
	  Alter Table TbEntradaProduto
	    Add DtConfIni Date
End;
IF not EXISTS(SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'TbEntradaProduto' AND
   COLUMN_NAME = 'HrInicio') begin
	  Alter Table TbEntradaProduto
	    Add HrInicio Time(7)
End;
IF not EXISTS(SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'TbEntradaLote' AND
   COLUMN_NAME = 'DtConfIni') begin
  	Alter Table TbEntradaLote
  	  Add DtConfIni Date
End;
IF not EXISTS(SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'TbEntradaLote' AND
   COLUMN_NAME = 'HrInicio') begin
  	Alter Table TbEntradaLote
  	  Add HrInicio Time(7)
End;
IF not EXISTS(SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'TbEntradaLote' AND
   COLUMN_NAME = 'DtConfFin') begin
  	Alter Table TbEntradaLote
	    Add DtConfFin Date
End;
IF not EXISTS(SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'TbEntradaLote' AND
   COLUMN_NAME = 'HrFinal') begin
  	Alter Table TbEntradaLote
  	  Add HrFinal Time(7)
End;
IF not EXISTS(SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'TbEntradaLote' AND
   COLUMN_NAME = 'CdUsuarioAuth') begin
  	Alter Table TbEntradaLote
	    Add CdUsuarioAuth Int Default Null
End;


SET ANSI_NULLS ON;
SET QUOTED_IDENTIFIER ON;
IF(EXISTS(SELECT * FROM  sys.triggers WHERE NAME = 'RegistrarChegadaCarga'))
    BEGIN
        DROP TRIGGER [dbo].[RegistrarChegadaCarga];
    END;
GO
CREATE TRIGGER [dbo].[RegistrarChegadaCarga] ON [dbo].[tbEntrada]
AFTER INSERT
AS
BEGIN
    SET NOCOUNT ON;
    IF (SELECT vlParametro FROM  tbParametro WHERE NmParametro = 'EntGerarRegCargaAutomatico') = 1
        BEGIN
            UPDATE Ent
            SET
                Ent.DtChegadaCarga = CAST(GETDATE() AS DATE)
                , Ent.HrChegadaCarga = CAST(GETDATE() AS TIME)
				, Ent.TpMarcacao = 0
            FROM TbEntrada Ent
                INNER JOIN Inserted I ON I.CdEntrada = Ent.CdEntrada;
        END;
END;


IF not EXISTS(SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'TbEntradaConferenciaLote' AND
   COLUMN_NAME = 'DtConfIni') begin
  	Alter Table TbEntradaConferenciaLote
   	  Add DtConfIni Date
End;
IF not EXISTS(SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'TbEntradaConferenciaLote' AND
   COLUMN_NAME = 'HrInicio') begin
  	Alter Table TbEntradaConferenciaLote
  	  Add HrInicio Time(7)
End;
IF not EXISTS(SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'TbEntradaConferenciaLote' AND
   COLUMN_NAME = 'DtConfFin') begin
  	Alter Table TbEntradaConferenciaLote
  	  Add DtConfFin Date
End;
IF not EXISTS(SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'TbEntradaConferenciaLote' AND
   COLUMN_NAME = 'HrFinal') begin
  	Alter Table TbEntradaConferenciaLote
  	  Add HrFinal Time(7)
End;
IF not EXISTS(SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'TbEntradaConferenciaLote' AND
   COLUMN_NAME = 'CdUsuarioAuth') begin
  	Alter Table TbEntradaConferenciaLote
  	  Add CdUsuarioAuth Int
End;
IF not EXISTS(SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'TbEntradaConferenciaLote' AND
   COLUMN_NAME = 'PrintEan') begin
  	Alter Table TbEntradaConferenciaLote
  	  Add PrintEan Int Default 0
End;
if Not Exists (Select CdParametro from tbParametro Where nmParametro = 'EtqInibeCdProduto')
   Insert Into TbParametro Values (Coalesce((select Max(CdParametro) From TbParametro), 0)+1, 'EtqInibeCdProduto', 0)
if Not Exists (Select CdParametro from tbParametro Where nmParametro = 'EntForcarRegChegadaCarga')
   Insert Into TbParametro Values (Coalesce((select Max(CdParametro) From TbParametro), 0)+1, 'EntForcarRegChegadaCarga', 0)
if Not Exists (Select CdParametro from tbParametro Where nmParametro = 'EntGerarRegCargaAutomatico')
   Insert Into TbParametro Values (Coalesce((select Max(CdParametro) From TbParametro), 0)+1, 'EntGerarRegCargaAutomatico', 0)
if Not Exists (Select CdParametro from tbParametro Where nmParametro = 'SNGPC_Confronta_Quantidade_Lote_Venda')
   Insert Into TbParametro Values (Coalesce((select Max(CdParametro) From TbParametro), 0)+1, 'SNGPC_Confronta_Quantidade_Lote_Venda', 0)
 
If not Exists (Select CdFuncao From TbFuncao where CdFuncao = 84)
   Insert Into TbFuncao Values (84, 'Registrar Chegada de Carga', 1);
If Not Exists (Select CdFuncao From tbUsuarioPerfilFuncao where CdFuncao = 84 and CdPerfil = 1)
   Insert Into  tbUsuarioPerfilFuncao Values (1, 84);
If not Exists (Select CdFuncao From TbFuncao where CdFuncao = 85)
   Insert Into TbFuncao Values (85, 'SNGPC_alterar_sugestao_lotes_SNGPC_Xml', 1);
If Not Exists (Select CdFuncao From tbUsuarioPerfilFuncao where CdFuncao = 85 and CdPerfil = 1)
   Insert Into  tbUsuarioPerfilFuncao Values (1, 85);   
--Impacto: LinxWMS_Coletor
  
IF not EXISTS(SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'TbEnderecoSetor' AND
              COLUMN_NAME = 'ControlSNGPC') begin
	  Alter Table TbEnderecoSetor
	    Add ControlSNGPC Bit Default 0
End;

IF not EXISTS(SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'TbSeparacaoVolumePrd' AND
              COLUMN_NAME = 'ControlSNGPC') begin
	  Alter Table TbSeparacaoVolumePrd
	    Add ControlSNGPC Bit Default 0
End;




